@@ -1042,18 +1042,19 @@ isns_portal_to_attr_list(const isns_portal_info_t *portal,
 	return 1;
 }
 
+static char portal_buf[1024];
+
 const char *
 isns_portal_string(const isns_portal_info_t *portal)
 {
 	const struct sockaddr_in6 *six = &portal->addr;
-	static char	buffer[128];
 	char		abuf[128];
 
 	inet_ntop(six->sin6_family, &six->sin6_addr, abuf, sizeof(abuf));
-	snprintf(buffer, sizeof(buffer), "[%s]:%d/%s",
+	snprintf(portal_buf, sizeof(portal_buf), "[%s]:%d/%s",
 			abuf, ntohs(six->sin6_port),
 			(portal->proto == IPPROTO_UDP)? "udp" : "tcp");
-	return buffer;
+	return portal_buf;
 }
 
 int
@@ -1128,25 +1129,29 @@ isns_portal_parse(isns_portal_info_t *portal,
  * Attribute type NIL
  */
 static int
-isns_attr_type_nil_encode(buf_t *bp, const isns_value_t *value)
+isns_attr_type_nil_encode(buf_t *bp,
+		__attribute__((unused))const isns_value_t *value)
 {
 	return buf_put32(bp, 0);
 }
 
 static int
-isns_attr_type_nil_decode(buf_t *bp, size_t len, isns_value_t *value)
+isns_attr_type_nil_decode(__attribute__((unused))buf_t *bp, size_t len,
+		__attribute__((unused))isns_value_t *value)
 {
 	return len == 0;
 }
 
 static void
-isns_attr_type_nil_print(const isns_value_t *value, char *buf, size_t size)
+isns_attr_type_nil_print(__attribute__((unused))const isns_value_t *value,
+		char *buf, size_t size)
 {
 	snprintf(buf, size, "<empty>");
 }
 
 static int
-isns_attr_type_nil_parse(isns_value_t *value, const char *string)
+isns_attr_type_nil_parse(__attribute__((unused))isns_value_t *value,
+		const char *string)
 {
 	if (string && *string)
 		return 0;
